@@ -9,7 +9,7 @@ package Rex::Interface::File::OpenSSH;
 use strict;
 use warnings;
 
-our $VERSION = '1.6.0'; # VERSION
+our $VERSION = '1.9.0'; # VERSION
 
 use Fcntl;
 use Rex::Interface::Fs;
@@ -59,12 +59,16 @@ sub read {
   my ( $self, $len ) = @_;
 
   my $sftp = Rex::get_sftp();
-  my $buf = $sftp->read( $self->{fh}, $len );
+  my $buf  = $sftp->read( $self->{fh}, $len );
   return $buf;
 }
 
 sub write {
   my ( $self, $buf ) = @_;
+
+  utf8::encode($buf)
+    if Rex::Config->get_write_utf8_files && utf8::is_utf8($buf);
+
   my $sftp = Rex::get_sftp();
   $sftp->write( $self->{fh}, $buf );
 }
